#ifndef PACKER_EXTENSIONS_H
#define PACKER_EXTENSIONS_H

#include "svn_client.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


  /** Return the numerical value of the head revision of the repository
   * containing the resource @a URL. @a ctx is required for possible repository
   * authentication.
   */
  svn_error_t *
  svn_client_head_revision(const char *URL,
			   svn_revnum_t *revnum,
			   svn_client_ctx_t *ctx,
			   apr_pool_t *pool);
  
  /** Return the url of the repository containing the resource @a URL
   */
  svn_error_t *
  svn_client_repos_root(const char *URL,
			svn_stringbuf_t ** root_url,
			svn_client_ctx_t *ctx,
			apr_pool_t *pool);
  
  /** Copy local file into the repository without needing a local working
   * copy.
   */
  svn_error_t *
  svn_client_put(svn_client_commit_info_t **commit_info,
		 const char *src_path,
		 const char *dst_url,
		 svn_boolean_t forbid_overwrite,
		 svn_client_ctx_t *ctx,
		 apr_pool_t *pool);

  /**
   * Callback function which collects the kind (file, dir, none) of a resource
   */
  typedef void (*svn_report_kind_func_t) (void *baton,
					  const char *path,
					  svn_node_kind_t kind);

  svn_error_t *
  svn_client_kind (const char *path_or_url,
		   const svn_opt_revision_t *revision,
		   svn_report_kind_func_t report_kind_func,
		   void* report_kind_baton,
		   svn_client_ctx_t *ctx,
		   apr_pool_t *pool);

svn_error_t *
svn_client_prop_set (svn_client_commit_info_t **commit_info,
		     const char *propname,
		     const svn_string_t *propval,
		     const char *target,
		     svn_client_ctx_t *ctx,
		     apr_pool_t *pool);

svn_error_t*
svn_client_get_delta_editor(svn_client_commit_info_t **commit_info,
			    const char* root_url,
			    svn_client_ctx_t *ctx,
			    const char* message,
			    const svn_delta_editor_t **editor,
			    void** edit_baton,
			    apr_pool_t *pool);

svn_error_t *
svn_client_rename (svn_client_commit_info_t **commit_info,
		   const char *src_path,
		   const svn_opt_revision_t *src_revision,
		   const char *dst_path,
		   svn_boolean_t force,
		   svn_client_ctx_t *ctx,
		   apr_pool_t *pool);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif  /* PACKER_EXTENSIONS_H */
